@@ -21,8 +21,9 @@ from __future__ import annotations
 
 import getpass
 import logging
-import secrets
-import string
+import sys
+
+from typing import NoReturn
 
 
 logger = logging.getLogger(__name__)
@@ -32,21 +33,54 @@ __author__: str = "Michael Sasser"
 __email__: str = "Michael@MichaelSasser.org"
 
 
-SPECIAL = "!§$%&/()=?.,;:_-#+*~{}[]°^@<>|\\"
-ALPHABET = string.ascii_letters + string.digits + SPECIAL
-
-
-def ask_password() -> str:
+def create_user(user: str, admin: bool | None = None) -> str | NoReturn:
     """Ask the user to create a password.
 
     The user will be asked twice for a password. After
     that the function compares the two entered passwords. If they are the
-    same, even when they are empty, the function will return the password.
+    same, and not empty, the function will ask the user if the data is correct
+    without disclosing the password.
 
-    Notes
-    -----
-    Keep in mind: When the user presses enter twice, without entering a
-    password, the function will return an empty `str`. **This is by-design**.
+    Parameters
+    ----------
+    user : str
+        The username.
+    admin : bool or none, default is None
+        True, if the user will be an admin,
+        False, if the user will not have eleveted permissions.
+        None, if the admin permissions are not an criteria. The field will
+        be omitted in the data.
+
+    Returns
+    -------
+    password : str
+        The user entered password.
+
+    """
+    try:
+        passwd = ask_password()
+
+        print("-" * 52)
+        print("Please check, if the entered information is correct:")
+        print(f"  Username: {user}")
+        print("  Password: (REDACTED)")
+        if admin is not None:
+            print(f"  Admin:    {'yes' if admin else 'no'}")
+        print("-" * 52)
+
+        if ask_question():
+            return passwd
+        sys.exit(1)
+    except KeyboardInterrupt:
+        sys.exit(1)
+
+
+def ask_password() -> str | NoReturn:
+    """Ask the user to create a password.
+
+    The user will be asked twice for a password. After
+    that the function compares the two entered passwords. If they are the
+    same, and not empty, the function will return the password.
 
     Parameters
     ----------
@@ -55,7 +89,7 @@ def ask_password() -> str:
     Returns
     -------
     password : str
-        The user entered password. The string might me empty!
+        The user entered password.
 
     """
     passwd: str | None = None
@@ -63,70 +97,17 @@ def ask_password() -> str:
 
     while True:
         passwd = getpass.getpass()
+        if passwd == "":
+            print("The password must not be empty!")
+            continue
         passwd2 = getpass.getpass("Password (again): ")
         if passwd == passwd2:
             break
+        print("The entered passwords do not match. Please try again!")
 
     return passwd
 
 
-def gen_password(
-    length: int = 16,
-    min_digits: int = 3,
-    min_special: int = 1,
-    max_special: int = 3,
-) -> str:
-    """Generate a password.
-
-    It uses lower- and uppercase
-    characters, digits and some special characters, you can find in the
-    ``SPECIAL`` variable in this file.
-
-    It uses at least:
-
-    - ``min_digits`` digits
-    - ``min_special`` special characters
-
-    It uses maximal:
-
-    - ``max_special`` special characters
-
-    The rest are lower- and uppercase characters.
-
-    Parameters
-    ----------
-    length : int, defautl=16
-        The desired length of the password to generate.
-    min_digits : int, default=3
-        The desired minimum of digits of the password.
-    min_special : int, default=1
-        The desired minimum of special characters of the password.
-    max_special : int, default=3
-        The desired maximum of special characters of the password.
-
-    Returns
-    -------
-    password : str
-        The generated password.
-
-    """
-
-    while True:
-        password = "".join(secrets.choice(ALPHABET) for _ in range(length))
-
-        # pylint: disable=chained-comparison
-
-        if (
-            any(c.islower() for c in password)
-            and any(c.isupper() for c in password)
-            and sum(c.isdigit() for c in password) >= min_digits
-            and min_special
-            <= sum(c in SPECIAL for c in password)
-            <= max_special
-        ):
-            return password
-
-
 def ask_question(question: str = "Is everything correct?") -> bool:
     """Asks the user a simple yes/no a question.
 
